@@ -1,5 +1,5 @@
 /*
- * (c) 2018 by van Hauser / THC
+ * (c) 2019 by van Hauser / THC
  *
  * THC IPv6 Attack Library Header Files
  *
@@ -17,9 +17,9 @@
   #include <openssl/rsa.h>
 #endif
 
-#define VERSION 	"v3.4"
+#define VERSION 	"v3.6"
 #define AUTHOR 		"van Hauser / THC <vh@thc.org>"
-#define RESOURCE	"www.thc.org"
+#define RESOURCE	"www.github.com/vanhauser-thc/thc-ipv6"
 
 #define THC_SPLITCONNECT_PORT 64446
 #define THC_SPLITCONNECT_FROM_BYTE 0xff
